// Copyright (c) Valerie Aurora https://valerieaurora.org/
//
// See COPYING for license information
//
//go:build darwin || linux

package main

import (
	"log"
	"syscall"

	"golang.org/x/sys/unix"
)

func (f *fragQuiz) setTTL(network string, r syscall.RawConn, ttl int) {
	var level, opt int
	switch network {
	case "udp4", "tcp4":
		level = syscall.IPPROTO_IP
		opt = unix.IP_TTL
	case "udp6", "tcp6":
		level = syscall.IPPROTO_IPV6
		opt = unix.IPV6_UNICAST_HOPS
	default:
		log.Panicf("unknown network %v", network)
	}

	rcErr := r.Control(func(fd uintptr) {
		err := syscall.SetsockoptInt(int(fd), level, opt, ttl)
		if err != nil {
			log.Fatalf("couldn't set TTL for %v socket: %v", network, err)
		}
	})
	if rcErr != nil {
		log.Fatalf("couldn't execute setsockopt on raw socket for %v socket: %v", network, rcErr)
	}
}
